rss_feed

# Org Markup Advanced Reference

home Home
pages orgmode
pages markup

A lot of the below examples rely on external binaries being installed on your system.

## Formula

You can use latex fragments to generate formula images.

    1
    2
    3
    \begin{equation}
    x=\sqrt{b}
    \end{equation}

## Graphs

You can generate graphviz diagrams using dot like in the example below.

    1
    2
    3
    4
    5
    digraph G {
    graph [ dpi = 300 ];
      lisp -> common_lisp;
      lisp -> scheme;
    }

## Musical Notation

If you install lilypond you can generate music notation images.

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
      \version "2.12.3"
      #(set-global-staff-size 38)
      \paper{
         indent=10\mm
         line-width=400\mm
         oddFooterMarkup=##f
         oddHeaderMarkup=##f
         bookTitleMarkup=##f
         scoreTitleMarkup=##f
      }
      \relative c' {
        c d e f g a b c b a g f e d c d
    }